local config = CreateFrame("Frame", "ICoor_Config", UIParent);

local function LoadFight()
	ICoorM:LoadFight(config.master.i);
end

local function LoadFightConfig(i)
	config.master.i = i;
	config.master.fightname:SetText(ICoorM_Fight[i].Name);
	config.master.spell:SetText(ICoorM_Fight[i].Spell);
	config.master.player1:SetText(ICoorM_Fight[i].Rotation[1]);
	config.master.player2:SetText(ICoorM_Fight[i].Rotation[2]);
	config.master.player3:SetText(ICoorM_Fight[i].Rotation[3]);
	config.master.player4:SetText(ICoorM_Fight[i].Rotation[4]);
	config.master.player5:SetText(ICoorM_Fight[i].Rotation[5]);
end

local function NewFight()
	local new = {
		Name = "New Fight",
		Spell = "Ability",
		Cooldown = 8,
		Rotation = {"None", "None", "None", "None", "None"},
	};
	table.insert(ICoorM_Fight, new);

	UIDropDownMenu_Initialize(config.master.currentFight, function(self, level)   
		local info = UIDropDownMenu_CreateInfo()
		local channelOptions = {};
		for i = 1, table.getn(ICoorM_Fight) do
			channelOptions[i] = ICoorM_Fight[i].Name;
		end

		for k,v in pairs(channelOptions) do
			info = UIDropDownMenu_CreateInfo();
			info.text = v;
			info.value = v;
			info.func = function(self)
				UIDropDownMenu_SetSelectedID(config.master.currentFight, self:GetID());
				LoadFightConfig(self:GetID());
			end
			UIDropDownMenu_AddButton(info, level);
		end 
	end);
	UIDropDownMenu_SetSelectedID(config.master.currentFight, 1);
	LoadFightConfig(1);
end

local function RemoveFight()
	if table.getn(ICoorM_Fight) == 1 then return end
	table.remove(ICoorM_Fight, config.master.i);

	UIDropDownMenu_Initialize(config.master.currentFight, function(self, level)   
		local info = UIDropDownMenu_CreateInfo()
		local channelOptions = {};
		for i = 1, table.getn(ICoorM_Fight) do
			channelOptions[i] = ICoorM_Fight[i].Name;
		end

		for k,v in pairs(channelOptions) do
			info = UIDropDownMenu_CreateInfo();
			info.text = v;
			info.value = v;
			info.func = function(self)
				UIDropDownMenu_SetSelectedID(config.master.currentFight, self:GetID());
				LoadFightConfig(self:GetID());
			end
			UIDropDownMenu_AddButton(info, level);
		end 
	end);
	UIDropDownMenu_SetSelectedID(self.master.currentFight, 1);
	LoadFightConfig(1);
end

local function OnEvent(self, event, arg1)
	if arg1 ~= "InterruptCoordinator" then return end
	self.name = "Interrupt Coordinator";

	self.title = self:CreateFontString("ICoor_self_Title", "OVERLAY", "GameFontNormal");
	self.title:SetFont(GameFontNormal:GetFont(), 16, "OUTLINE");
	self.title:SetPoint("TOPLEFT", self, 10, -10);
	self.title:SetText(self.name);

	self.spellBox = CreateFrame("EditBox", "ICoor_self_Spell", self, "InputBoxTemplate");
	self.spellBox:SetPoint("TOPLEFT", self, 10, -40);
	self.spellBox:SetSize(250, 25);
	self.spellBox:SetAutoFocus(false);
	self.spellBox:SetMultiLine(false);
	self.spellBox:SetText(ICoor_Saves.InterruptToTrack);
	self.spellBox:SetCursorPosition(0);
	self.spellBox:SetScript("OnEnterPressed", function(self) self:ClearFocus() end);

	self.spelltitle = self:CreateFontString("ICoor_self_Spell_Title", "ARTWORK", "GameFontNormal");
	self.spelltitle:SetFont(GameFontNormal:GetFont(), 12, "OUTLINE");
	self.spelltitle:SetPoint("LEFT", self.spellBox, "RIGHT", 10, 0);
	self.spelltitle:SetText("Your main interrupt spell");

	self.queue = CreateFrame("CheckButton", "ICoor_self_Queue", self, "InterfaceOptionsCheckButtonTemplate");
	self.queue:SetPoint("TOPLEFT", self.spellBox, "BOTTOMLEFT", 0, -10);
	self.queue:SetChecked(ICoor_Saves.Queue);
	self.queue:SetHitRectInsets(0, -200, 0, 0);
	self.queuetitle = self:CreateFontString("ICoor_self_Queue_Title", "ARTWORK", "GameFontNormal");
	self.queuetitle:SetFont(GameFontNormal:GetFont(), 12, "OUTLINE");
	self.queuetitle:SetPoint("LEFT", self.queue, "Right", 10, 0);
	self.queuetitle:SetText("Show Queue");

	self.locked = CreateFrame("CheckButton", "ICoor_self_Locked", self, "InterfaceOptionsCheckButtonTemplate");
	self.locked:SetPoint("TOPLEFT", self.queue, "BOTTOMLEFT", 0, -10);
	self.locked:SetChecked(ICoor_Saves.Locked);
	self.locked:SetHitRectInsets(0, -200, 0, 0);
	self.lockedtitle = self:CreateFontString("ICoor_self_Locked_Title", "ARTWORK", "GameFontNormal");
	self.lockedtitle:SetFont(GameFontNormal:GetFont(), 12, "OUTLINE");
	self.lockedtitle:SetPoint("LEFT", self.locked, "Right", 10, 0);
	self.lockedtitle:SetText("Movement locked");

	self.play = CreateFrame("CheckButton", "ICoor_self_Play", self, "InterfaceOptionsCheckButtonTemplate");
	self.play:SetPoint("TOPLEFT", self.locked, "BOTTOMLEFT", 0, -10);
	self.play:SetChecked(ICoor_Saves.Playsound);
	self.play:SetHitRectInsets(0, -200, 0, 0);
	self.playtitle = self:CreateFontString("ICoor_self_Play_Title", "ARTWORK", "GameFontNormal");
	self.playtitle:SetFont(GameFontNormal:GetFont(), 12, "OUTLINE");
	self.playtitle:SetPoint("LEFT", self.play, "Right", 10, 0);
	self.playtitle:SetText("Play warning sound");

	self.isshown = CreateFrame("CheckButton", "ICoor_self_IsShown", self, "InterfaceOptionsCheckButtonTemplate");
	self.isshown:SetPoint("TOPLEFT", self.play, "BOTTOMLEFT", 0, -10);
	self.isshown:SetChecked(ICoor_Saves.Playsound);
	self.isshown:SetHitRectInsets(0, -200, 0, 0);
	self.isshowntitle = self:CreateFontString("ICoor_self_Play_Title", "ARTWORK", "GameFontNormal");
	self.isshowntitle:SetFont(GameFontNormal:GetFont(), 12, "OUTLINE");
	self.isshowntitle:SetPoint("LEFT", self.isshown, "Right", 10, 0);
	self.isshowntitle:SetText("Show Addon");

	self.okay = function(self)
		ICoor_Saves.InterruptToTrack = self.spellBox:GetText();
		ICoor_Saves.Queue = self.queue:GetChecked();
		ICoor_Saves.Locked = self.locked:GetChecked();
		ICoor_Saves.Playsound = self.play:GetChecked();
		ICoor_Saves.IsShown = self.isshown:GetChecked();
		ICoor:ToggleAddon();
	end

	self.cancel = function(self)
		self.spellBox:SetText(ICoor_Saves.InterruptToTrack);
		self.queue:SetChecked(ICoor_Saves.Queue);
		self.locked:SetChecked(ICoor_Saves.Locked);
		self.play:SetChecked(ICoor_Saves.Playsound);
		self.isshown:SetChecked(ICoor_Saves.IsShown);
	end
	InterfaceOptions_AddCategory(self);

	self.master = CreateFrame("Frame", "ICoorM_Config", self);
	self.master.name = "Master";
	self.master.parent = self.name;
	self.master.i = 1;

	self.master.title = self.master:CreateFontString("ICoorM_Config_Title", "OVERLAY", "GameFontNormal");
	self.master.title:SetFont(GameFontNormal:GetFont(), 16, "OUTLINE");
	self.master.title:SetPoint("TOPLEFT", self.master, 10, -10);
	self.master.title:SetText("Interrupt Coordinator Master (for raid leader only!)");

	self.master.currentFight = CreateFrame("Button", "ICoorM_Config_CurrentFight", self.master, "UIDropDownMenuTemplate");
	self.master.currentFight:SetPoint("TOPLEFT", self.master.title, "BOTTOMLEFT", 0, -10);
	self.master.currentFight:SetSize(50, 25);

	self.master.newFight = CreateFrame("Button", "ICoorM_Confi_NewFight", self.master, "UIPanelButtonTemplate");
	self.master.newFight:SetPoint("LEFT", self.master.currentFight, "RIGHT", 100, 0);
	self.master.newFight:SetSize(100, 25);
	self.master.newFight:SetText("New Fight");
	self.master.newFight:RegisterForClicks("AnyUp");
	self.master.newFight:SetScript("OnMouseUp", NewFight);

	self.master.removeFight = CreateFrame("Button", "ICoorM_Config_RemoveFight", self.master, "UIPanelButtonTemplate");
	self.master.removeFight:SetPoint("LEFT", self.master.newFight, "RIGHT", 10, 0);
	self.master.removeFight:SetSize(100, 25);
	self.master.removeFight:SetText("Remove Fight");
	self.master.removeFight:RegisterForClicks("AnyUp");
	self.master.removeFight:SetScript("OnMouseUp", RemoveFight);

	self.master.loadFight = CreateFrame("Button", "ICoorM_Config_LoadFight", self.master, "UIPanelButtonTemplate");
	self.master.loadFight:SetPoint("LEFT", self.master.removeFight, "RIGHT", 10, 0);
	self.master.loadFight:SetSize(100, 25);
	self.master.loadFight:SetText("Load Fight");
	self.master.loadFight:RegisterForClicks("AnyUp");
	self.master.loadFight:SetScript("OnMouseUp", LoadFight);

	self.master.enabled = CreateFrame("CheckButton", "ICoorM_Config_Enable", self.master, "InterfaceOptionsCheckButtonTemplate");
	self.master.enabled:SetPoint("TOPLEFT", self.master.loadFight, "BOTTOMLEFT", 0, -10);
	self.master.enabled:SetChecked(ICoorM_Fight.Enabled);
	self.master.enabled:SetHitRectInsets(0, -200, 0, 0);
	self.master.enabledtitle = self.master:CreateFontString("ICoorM_Config_Enable_Title", "ARTWORK", "GameFontNormal");
	self.master.enabledtitle:SetFont(GameFontNormal:GetFont(), 12, "OUTLINE");
	self.master.enabledtitle:SetPoint("LEFT", self.master.enabled, "Right", 10, 0);
	self.master.enabledtitle:SetText("Enable this feature");

	self.master.fightname = CreateFrame("EditBox", "ICoorM_Config_Name", self.master, "InputBoxTemplate");
	self.master.fightname:SetPoint("TOPLEFT", self.master.currentFight, "BOTTOMLEFT", 0, -10);
	self.master.fightname:SetSize(250, 25);
	self.master.fightname:SetAutoFocus(false);
	self.master.fightname:SetMultiLine(false);
	self.master.fightname:SetText(ICoorM_Fight[1].Name);
	self.master.fightname:SetCursorPosition(0);
	self.master.fightname:SetScript("OnEnterPressed", function(self)
		ICoorM_Fight[config.master.i].Name = self:GetText(); 
		self:ClearFocus() 
	end);

	self.master.fightnametitle = self.master:CreateFontString("ICoor_Config_Name_Title", "ARTWORK", "GameFontNormal");
	self.master.fightnametitle:SetFont(GameFontNormal:GetFont(), 12);
	self.master.fightnametitle:SetPoint("LEFT", self.master.fightname, "RIGHT", 10, 0);
	self.master.fightnametitle:SetText("Name of fight");

	self.master.spell = CreateFrame("EditBox", "ICoorM_Config_Spell", self.master, "InputBoxTemplate");
	self.master.spell:SetPoint("TOPLEFT", self.master.fightname, "BOTTOMLEFT", 0, -10);
	self.master.spell:SetSize(250, 25);
	self.master.spell:SetAutoFocus(false);
	self.master.spell:SetMultiLine(false);
	self.master.spell:SetText(ICoorM_Fight[1].Spell);
	self.master.spell:SetCursorPosition(0);
	self.master.spell:SetScript("OnEnterPressed", function(self)
		ICoorM_Fight[config.master.i].Spell = self:GetText();  
		self:ClearFocus() 
	end);

	self.master.spelltitle = self.master:CreateFontString("ICoor_Config_Spell_Title", "ARTWORK", "GameFontNormal");
	self.master.spelltitle:SetFont(GameFontNormal:GetFont(), 12);
	self.master.spelltitle:SetPoint("LEFT", self.master.spell, "RIGHT", 10, 0);
	self.master.spelltitle:SetText("Spell to interrupt");

	self.master.rotation = self.master:CreateFontString("ICoor_Config_Rotation", "ARTWORK", "GameFontNormal");
	self.master.rotation:SetFont(GameFontNormal:GetFont(), 12);
	self.master.rotation:SetPoint("TOPLEFT", self.master.spell, "BOTTOMLEFT", 0, -10);
	self.master.rotation:SetText("Caster rotation:");

	self.master.player1 = CreateFrame("EditBox", "ICoorM_Config_Player1", self.master, "InputBoxTemplate");
	self.master.player1:SetPoint("TOPLEFT", self.master.rotation, "BOTTOMLEFT", 0, -10);
	self.master.player1:SetSize(250, 25);
	self.master.player1:SetAutoFocus(false);
	self.master.player1:SetMultiLine(false);
	self.master.player1:SetText(ICoorM_Fight[1].Rotation[1]);
	self.master.player1:SetCursorPosition(0);
	self.master.player1:SetScript("OnEnterPressed", function(self) 
		ICoorM_Fight[config.master.i].Rotation[1] = self:GetText(); 
		self:ClearFocus() 
	end);

	self.master.player2 = CreateFrame("EditBox", "ICoorM_Config_Player2", self.master, "InputBoxTemplate");
	self.master.player2:SetPoint("TOPLEFT", self.master.player1, "BOTTOMLEFT", 0, -10);
	self.master.player2:SetSize(250, 25);
	self.master.player2:SetAutoFocus(false);
	self.master.player2:SetMultiLine(false);
	self.master.player2:SetText(ICoorM_Fight[1].Rotation[2]);
	self.master.player2:SetCursorPosition(0);
	self.master.player2:SetScript("OnEnterPressed", function(self) 
		ICoorM_Fight[config.master.i].Rotation[2] = self:GetText(); 
		self:ClearFocus() 
	end);

	self.master.player3 = CreateFrame("EditBox", "ICoorM_Config_Player3", self.master, "InputBoxTemplate");
	self.master.player3:SetPoint("TOPLEFT", self.master.player2, "BOTTOMLEFT", 0, -10);
	self.master.player3:SetSize(250, 25);
	self.master.player3:SetAutoFocus(false);
	self.master.player3:SetMultiLine(false);
	self.master.player3:SetText(ICoorM_Fight[1].Rotation[3]);
	self.master.player3:SetCursorPosition(0);
	self.master.player3:SetScript("OnEnterPressed", function(self) 
		ICoorM_Fight[config.master.i].Rotation[3] = self:GetText(); 
		self:ClearFocus() 
	end);

	self.master.player4 = CreateFrame("EditBox", "ICoorM_Config_Player4", self.master, "InputBoxTemplate");
	self.master.player4:SetPoint("TOPLEFT", self.master.player3, "BOTTOMLEFT", 0, -10);
	self.master.player4:SetSize(250, 25);
	self.master.player4:SetAutoFocus(false);
	self.master.player4:SetMultiLine(false);
	self.master.player4:SetText(ICoorM_Fight[1].Rotation[4]);
	self.master.player4:SetCursorPosition(0);
	self.master.player4:SetScript("OnEnterPressed", function(self) 
		ICoorM_Fight[config.master.i].Rotation[4] = self:GetText(); 
		self:ClearFocus() 
	end);

	self.master.player5 = CreateFrame("EditBox", "ICoorM_Config_Player5", self.master, "InputBoxTemplate");
	self.master.player5:SetPoint("TOPLEFT", self.master.player4, "BOTTOMLEFT", 0, -10);
	self.master.player5:SetSize(250, 25);
	self.master.player5:SetAutoFocus(false);
	self.master.player5:SetMultiLine(false);
	self.master.player5:SetText(ICoorM_Fight[1].Rotation[5]);
	self.master.player5:SetCursorPosition(0);
	self.master.player5:SetScript("OnEnterPressed", function(self) 
		ICoorM_Fight[config.master.i].Rotation[5] = self:GetText(); 
		self:ClearFocus() 
	end);

	UIDropDownMenu_Initialize(self.master.currentFight, function(self, level)   
		local info = UIDropDownMenu_CreateInfo()
		local channelOptions = {};
		for i = 1, table.getn(ICoorM_Fight) do
			channelOptions[i] = ICoorM_Fight[i].Name;
		end

		for k,v in pairs(channelOptions) do
			info = UIDropDownMenu_CreateInfo();
			info.text = v;
			info.value = v;
			info.func = function(self)
				UIDropDownMenu_SetSelectedID(config.master.currentFight, self:GetID());
				LoadFightConfig(self:GetID());
			end
			UIDropDownMenu_AddButton(info, level);
		end 
	end);
	UIDropDownMenu_SetSelectedID(config.master.currentFight, 1);

	self.master.okay = function(self)
		ICoorM_Fight.Enabled = self.master.enabled:GetChecked();
	end

	self.master.cancel = function(self)
		self.master.enabled:SetChecked(ICoorM_Fight.Enabled);
	end
	InterfaceOptions_AddCategory(self.master);
end

config:RegisterEvent("ADDON_LOADED");
config:SetScript("OnEvent", OnEvent);